@@ -1,5 +1,5 @@
  /*
-  * @(#) tcpd.h 1.4 96/02/11 17:01:33
+  * @(#) tcpd.h 1.5 96/03/19 16:22:24
   * 
   * Author: Wietse Venema, Eindhoven University of Technology, The Netherlands.
   */
@@ -212,3 +212,8 @@ extern struct hostent *fix_gethostbyname();
 #define strtok	fix_strtok
 extern char *fix_strtok();
 #endif
+
+#ifdef LIBC_CALLS_STRTOK		/* libc calls strtok() */
+#define strtok	my_strtok
+extern char *my_strtok();
+#endif
